@@ -1,160 +1,12 @@
 # -*- encoding: utf-8 -*-
 
-from abc import abstractmethod, ABCMeta
-from base64 import b64encode, b64decode
-from urllib.request import urlopen
-from xml.dom.minidom import parse
-from xml.etree import ElementTree
-
-import requests
-from Crypto.PublicKey import RSA
-from Crypto.Signature import PKCS1_v1_5
 from lxml import etree
-from lxml.etree import XSLTParseError
 from Crypto.Hash import SHA256
 
 from .contants import TRASLADO, EGRESO, INGRESO, PAGO, COMPLEMENTO_CARTA_PORTE, COMPLEMENTO_PAGO
+from .generator_abstract import AbstractGeneratorXml
 from .utils import replace
 
-import os
-import logging
-
-
-class DTDResolver(etree.Resolver):
-    def resolve(self, url, id, context):
-        url = 'https://www.sat.gob.mx/sitio_internet/cfd/3/cadenaoriginal_3_3/cadenaoriginal_3_3.xslt'
-        print("Resolving URL '%s'" % url)
-        return self.resolve_string(
-            '<!ENTITY myentity "[resolved text: %s]">' % url, context)
-
-
-class AbstractGeneratorXml(object):
-    __metaclass__ = ABCMeta
-
-    def __init__(self, data):
-        self.global_data = data
-        self.data = data.get('data')
-        self.dir_xml = os.path.dirname(os.path.abspath(__file__))
-        self.dom = parse(self.dir_xml + '/comprobante.xml')
-        self.algoritmoSha = None
-        self.tipo_objeto = self.data.get('tipo') # I, E, P, T
-        self.complemento = self.data.get('complemento', '') # Pago, CartaPorte
-        self.tipo_transporte = self.data.get('tipo_transporte', '')
-        self.version = ''
-        self.cadena_original_value = ''
-
-    @property
-    def cadena_original(self) -> str:
-        return self.cadena_original_value
-
-    @abstractmethod
-    def generate_xml(self):
-        pass
-
-    def create_xml(self, certificado_file_cer64, certificado_file_pem64):
-        self.generate_xml()
-        if self.global_data.get('provider') == 'solucion_factible':
-            self.set_certificado(certificado_file_cer64)
-            self.set_sello(certificado_file_pem64)
-
-    def get_version(self):
-        return self.data.get('version')
-
-    def reset_dom(self):
-        self.dom = parse(self.dir_xml + '/comprobante.xml')
-
-    def get_xml(self):
-        return self.dom.toxml(encoding='UTF-8')
-
-    def get_xml_str(self):
-        return self.dom.toxml(encoding='UTF-8').decode('utf8')
-
-    def set_certificado(self, certificado64): #,certificado_file_cer):
-        """
-        Recibe el certificado abierto como archivo
-        :param certificado_file:
-        :return:
-        """
-        try:
-            logging.info('OBTENIENDO EL CERTIFICADO DEL XML')
-            #file = open(self.dir_xml + '//archivos//' + self.noCertificado + '.cer', 'rb')
-            logging.info('CERTIFICADO DEL XML DEL INGRESO_ID')
-            # certificado = certificado_file_cer.read()
-            # certificado64 = b64encode(certificado)
-            certificadoA = [certificado64[i:i + 76] for i in range(0, len(certificado64), 76)]
-            certificadoF = ''
-            for val in certificadoA:
-                if certificadoF != '':
-                    certificadoF += ' '
-                certificadoF += val.decode("utf-8")
-            self.dom.setAttribute('Certificado', certificadoF)
-            logging.info('SETEO DEL CERTIFICADO EN EL XML')
-        except Exception as e:
-            logging.error('Error al generar el certificado. Error: ' + str(e))
-            raise Exception(e)
-
-    def set_sello(self, certificado_file_pem64): #, certificado_file_pem):
-        try:
-            logging.info('OBTENIENDO EL SELLO DEL XML')
-            #file_pem = open(self.dir_xml + '/archivos/' + self.noCertificado + '.pem', 'rb')
-            # key = RSA.importKey(certificado_file_pem.read())
-            certificado_file_pem_bytes = b64decode(certificado_file_pem64)
-            key = RSA.importKey(certificado_file_pem_bytes)
-            logging.info('OBTENIENDO LA CADENA ORIGINAL DEL XML')
-            self.cadena_original_value = self.get_cadena_original(self.get_xml())
-            logging.info('LA CADENA ORIGINAL DEL XML')
-            digest = self.algoritmoSha.new()
-            digest.update(bytes(self.cadena_original_value))
-            signer = PKCS1_v1_5.new(key)
-            sign = signer.sign(digest)
-            sello = b64encode(sign)
-            self.dom.setAttribute('Sello', sello.decode("utf-8"))
-        except Exception as e:
-            logging.error('Error generar el sello. Error: ' + str(e))
-            raise Exception(e)
-
-    def get_cadena_original(self, xml):
-        try:
-            if type(xml) == str:
-                xml = xml.encode('utf-8')
-            xml = etree.fromstring(xml)
-            logging.info('PARSE DE LA CADENA ORIGINAL DEL XML')
-            logging.info(self.dir_xml)
-            xslt = etree.parse(self.dir_xml + '/cadenaoriginal_3_3_local/cadenaoriginal_3_3.xslt')
-            logging.info('XSLT CADENA ORIGINAL DEL XML')
-            parser = etree.XSLT(xslt)
-            logging.info('XSLT CADENA ORIGINAL DEL XML 2')
-            cadena_original = parser(xml)
-            logging.info('XSLT CADENA ORIGINAL DEL XML 3')
-            return cadena_original
-        except XSLTParseError as e:
-            logging.error(u"Hubo un error al generar la cadena original, por favor intente mas tarde: " + str(e))
-            raise Exception(u"Hubo un error al generar la cadena original, por favor intente mas tarde: " + str(e))
-        except Exception as e:
-            logging.error('Error al leer el archivo: cadenaoriginal_' + self.data.get('version') + '.xslt:' + str(e))
-            raise Exception(e)
-
-    @abstractmethod
-    def get_datos(self, xml):
-        pass
-
-    def get_xml_info(self, xml):
-        if type(xml) == str:
-            xml = xml.encode('utf-8')
-        root = ElementTree.fromstring(xml)
-        xmlinfo = {}
-        xmlinfo['xml'] = xml
-        xmlinfo['documento'] = root
-        indice = 0
-        for doc in root:
-            if doc.tag == '{http://www.sat.gob.mx/cfd/3}Complemento':
-                break
-            else:
-                indice += 1
-        for complemento_data in root[indice]:
-            xmlinfo['complemento'] = complemento_data
-        return xmlinfo
-
 
 class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
 
@@ -162,39 +14,6 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
         super(self.__class__, self).__init__(data)
         self.version = '3.3'
         self.algoritmoSha = SHA256
-        self.__cadena_original = ''
-
-    def get_datos(self,xml):
-        self.__cadena_original = self.get_cadena_original(xml)
-        xml_info = self.get_xml_info(xml)
-        return {
-            'cadena_original':str(self.__cadena_original),
-            'serie': xml_info['documento'].attrib['Serie'],
-            'fecha_emision': xml_info['documento'].attrib['Fecha'],
-            'no_certificado': xml_info['documento'].attrib['NoCertificado'],
-            'folio': xml_info['documento'].attrib['Folio'],
-            'uuid': xml_info['complemento'].attrib['UUID'],
-            'fecha_timbrado': xml_info['complemento'].attrib['FechaTimbrado'],
-            'sello_emisor': xml_info['complemento'].attrib['SelloCFD'],
-            'sello_sat': xml_info['complemento'].attrib['SelloSAT'],
-            'no_certificado_sat': xml_info['complemento'].attrib['NoCertificadoSAT'],
-        }
-
-    def get_datos_test(self,xml):
-        cadena_original = self.get_cadena_original(xml)
-        xml_info = self.get_xml_info(xml)
-        return {
-            'cadena_original': str(cadena_original),
-            'serie': xml_info['documento'].attrib['Serie'],
-            'fecha_emision': xml_info['documento'].attrib['Fecha'],
-            'no_certificado': xml_info['documento'].attrib['NoCertificado'],
-            'folio': xml_info['documento'].attrib['Folio'],
-            'uuid': '',
-            'fecha_timbrado': '',
-            'sello_emisor': '',
-            'sello_sat': '',
-            'no_certificado_sat': '',
-        }
 
     def generate_xml(self):
         self.reset_dom()
@@ -237,14 +56,15 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
         if self.data.get('confirmacion'):
             if len(self.data.get('confirmacion', [])) == 5:
                 dom.setAttribute('Confirmacion', self.data.get('confirmacion'))  # opcional
-        dom.appendChild(self.get_emisor())
-        dom.appendChild(self.get_receptor())
 
         if len(self.data.get('cfdi_relacionados', [])) > 0:
             if self.data.get('tipo_relacion', '') == '':
                 raise Exception('Debe especificar el tipo de relación de los documentos')
             dom.appendChild(self.get_cfdi_relacionados())
 
+        dom.appendChild(self.get_emisor())
+        dom.appendChild(self.get_receptor())
+
         if (self.tipo_objeto == INGRESO) or (self.tipo_objeto == EGRESO and not self.global_data.get('concepto_fijo')):
             dom.setAttribute('FormaPago', self.data.get('forma_pago'))
             dom.setAttribute('CondicionesDePago', self.data.get('condicion_pago'))
